==> haskell-hedgehog-1.2-18-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog
version:              1.2
visibility:           public
id:                   hedgehog-1.2-6PcYeqnRpof27D7X8ClW1m
key:                  hedgehog-1.2-6PcYeqnRpof27D7X8ClW1m
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  06f02b8b1b419c3116350f76ff4ed20c
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Barbie
    Hedgehog.Internal.Config Hedgehog.Internal.Discovery
    Hedgehog.Internal.Distributive Hedgehog.Internal.Exception
    Hedgehog.Internal.Gen Hedgehog.Internal.HTraversable
    Hedgehog.Internal.Opaque Hedgehog.Internal.Prelude
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hedgehog-1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hedgehog-1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog
hs-libraries:         HShedgehog-1.2-6PcYeqnRpof27D7X8ClW1m
depends:
    ansi-terminal-0.11.4-Bavr5INHzaUHF3VuHy0Lqz
    async-2.2.5-EP8h1wWlEwVFRsNBoUfgIV
    barbies-2.0.5.0-K0AjdmR6ltxLT30FLCjww6 base-4.16.4.0
    bytestring-0.11.4.0
    concurrent-output-1.10.20-BSXUgEmS9OHB3sRTAaPE8w containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2
    erf-2.0.0.0-5wUg0hFZ5TmCeYzfUgzGpS exceptions-0.10.4
    lifted-async-0.10.2.5-7rruRqL0X0eIGIr1s38x5e
    mmorph-1.2.0-86rQZSuTSAZIoeBosVXsFi
    monad-control-1.0.3.1-ATKYMnkFwQRIHXjVMGqTnF mtl-2.2.2
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4
    resourcet-1.2.6-5BnvDTZXmqJCsWMY1Zflgy stm-2.5.0.2
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 transformers-base-0.4.6-LVJhj8dU6PHCItv1DVbZFi
    wl-pprint-annotated-0.1.0.1-GlZzVuuvD02T3IoeiFuSS

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-1.2-24-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog
version:              1.2
visibility:           public
id:                   hedgehog-1.2-45sXUMtiCZS9ksRmbj0vBk
key:                  hedgehog-1.2-45sXUMtiCZS9ksRmbj0vBk
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  bda276cb78ea59b9f3421a09cf7b99d4
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Barbie
    Hedgehog.Internal.Config Hedgehog.Internal.Discovery
    Hedgehog.Internal.Distributive Hedgehog.Internal.Exception
    Hedgehog.Internal.Gen Hedgehog.Internal.HTraversable
    Hedgehog.Internal.Opaque Hedgehog.Internal.Prelude
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hedgehog-1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hedgehog-1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog
hs-libraries:         HShedgehog-1.2-45sXUMtiCZS9ksRmbj0vBk
depends:
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85
    barbies-2.0.5.0-G9BNtpxluxFIElE0bxNxVE base-4.16.4.0
    bytestring-0.11.4.0
    concurrent-output-1.10.21-HTN7wy5wvNF2sBo3ZbLc8b containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2
    erf-2.0.0.0-5wUg0hFZ5TmCeYzfUgzGpS exceptions-0.10.4
    lifted-async-0.10.2.5-AGUcV76wxJN49mM3NYhUwU
    mmorph-1.2.0-86rQZSuTSAZIoeBosVXsFi
    monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK mtl-2.2.2
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD stm-2.5.0.2
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN
    wl-pprint-annotated-0.1.0.1-21h7Z48YMr241LjtceCswg

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
